# miraicle

<img align="middle" src="https://img.shields.io/badge/Python-%3E%3D3.6-blue" />

<img align="middle" src="https://img.shields.io/badge/PyPi-v0.1.0-brightgreen?link=https://pypi.org/project/miraicle/0.1.0/" />

一个基于 mirai-api-http 的 Python SDK

## 安装
`pip install miraicle`
